@@ -86,6 +86,7 @@ typedef enum
  * @GEDIT_DOCUMENT_SAVE_IGNORE_MTIME: save file despite external modifications.
  * @GEDIT_DOCUMENT_SAVE_IGNORE_BACKUP: write the file directly without attempting to backup.
  * @GEDIT_DOCUMENT_SAVE_PRESERVE_BACKUP: preserve previous backup file, needed to support autosaving.
+ * @GEDIT_DOCUMENT_SAVE_IGNORE_INVALID_CHARS: do not save invalid characters.
  */
 typedef enum
 {
@@ -294,10 +295,10 @@ GMountOperation
 		*_gedit_document_create_mount_operation
 						(GeditDocument	     *doc);
 
-void			 _gedit_document_set_search_context	(GeditDocument          *doc,
+void			 gedit_document_set_search_context	(GeditDocument          *doc,
 								 GtkSourceSearchContext *search_context);
 
-GtkSourceSearchContext	*_gedit_document_get_search_context	(GeditDocument          *doc);
+GtkSourceSearchContext	*gedit_document_get_search_context	(GeditDocument          *doc);
 
 gboolean		 _gedit_document_get_empty_search	(GeditDocument		*doc);
 
