@@ -116,7 +116,7 @@ struct _GeditPreferencesDialogPrivate
 	GtkWidget	*plugin_manager_place_holder;
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (GeditPreferencesDialog, gedit_preferences_dialog, GTK_TYPE_DIALOG)
+G_DEFINE_TYPE_WITH_PRIVATE (GeditPreferencesDialog, gedit_preferences_dialog, GTK_TYPE_WINDOW)
 
 static void
 gedit_preferences_dialog_dispose (GObject *object)
@@ -129,37 +129,14 @@ gedit_preferences_dialog_dispose (GObject *object)
 	G_OBJECT_CLASS (gedit_preferences_dialog_parent_class)->dispose (object);
 }
 
-static void
-gedit_preferences_dialog_response (GtkDialog *dlg,
-                                   gint       res_id)
-{
-	gedit_debug (DEBUG_PREFS);
-
-	switch (res_id)
-	{
-		case GTK_RESPONSE_HELP:
-			gedit_app_show_help (GEDIT_APP (g_application_get_default ()),
-			                     GTK_WINDOW (dlg),
-			                     NULL,
-			                     "index#configure-gedit");
-			break;
-
-		default:
-			gtk_widget_destroy (GTK_WIDGET (dlg));
-	}
-}
-
 static void
 gedit_preferences_dialog_class_init (GeditPreferencesDialogClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
-	GtkDialogClass *dialog_class = GTK_DIALOG_CLASS (klass);
 
 	object_class->dispose = gedit_preferences_dialog_dispose;
 
-	dialog_class->response = gedit_preferences_dialog_response;
-
 	/* Bind class to template */
 	gtk_widget_class_set_template_from_resource (widget_class,
 	                                             "/org/gnome/gedit/ui/gedit-preferences-dialog.ui");
@@ -850,7 +827,7 @@ install_scheme_clicked (GtkButton              *button,
 	chooser = gtk_file_chooser_dialog_new (_("Add Scheme"),
 					       GTK_WINDOW (dlg),
 					       GTK_FILE_CHOOSER_ACTION_OPEN,
-					       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					       _("_Cancel"), GTK_RESPONSE_CANCEL,
 					       _("A_dd Scheme"), GTK_RESPONSE_ACCEPT,
 					       NULL);
 
